do_fortran_indexing = 1;
a = 1;
isempty (a(logical (0)))
